summaryrefslogtreecommitdiff
path: root/gtk2_ardour/bundle_env_linux.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2015-12-07 12:38:11 -0500
committerPaul Davis <paul@linuxaudiosystems.com>2015-12-07 12:38:17 -0500
commitdafb9ee0e68ec137213cf915ec3282b2b51db72a (patch)
tree30d1db9a3d6074ca891eb01ab3f352eb2dd030ae /gtk2_ardour/bundle_env_linux.cc
parent3d79e3c116a13e455c0ea1083a25c81af9107764 (diff)
the variable used to define GTK2 RC files is GTK2_RC_FILES not GTK_RC_FILES (it was changed in GTK+ back in 2002
Diffstat (limited to 'gtk2_ardour/bundle_env_linux.cc')
-rw-r--r--gtk2_ardour/bundle_env_linux.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk2_ardour/bundle_env_linux.cc b/gtk2_ardour/bundle_env_linux.cc
index 259421b354..cc02445302 100644
--- a/gtk2_ardour/bundle_env_linux.cc
+++ b/gtk2_ardour/bundle_env_linux.cc
@@ -88,10 +88,10 @@ fixup_bundle_environment (int /*argc*/, char* argv[], string & localedir)
g_setenv ("SUIL_MODULE_DIR", (dir_path + "/lib").c_str(), 1);
g_setenv ("PATH", (dir_path + "/bin:" + std::string(g_getenv ("PATH"))).c_str(), 1);
/* unset GTK_RC_FILES so that we only load the RC files that we define
*/
- g_unsetenv ("GTK_RC_FILES");
+ g_unsetenv ("GTK2_RC_FILES");
/* Tell fontconfig where to find fonts.conf. Use the system version
if it exists, otherwise use the stuff we included in the bundle
@@ -88,10 +88,10 @@ fixup_bundle_environment (int /*argc*/, char* argv[], string & localedir)
g_setenv ("SUIL_MODULE_DIR", (dir_path + "/lib").c_str(), 1);
g_setenv ("PATH", (dir_path + "/bin:" + std::string(g_getenv ("PATH"))).c_str(), 1);
- /* unset GTK_RC_FILES so that we only load the RC files that we define
+ /* unset GTK2_RC_FILES so that we only load the RC files that we define
*/